@@ -512,7 +512,7 @@ brasero_app_set_parent (BraseroApp *app,
 	BraseroAppPrivate *priv;
 
 	priv = BRASERO_APP_PRIVATE (app);
-	priv->parent = gdk_window_foreign_new (parent_xid);
+	priv->parent = gdk_x11_window_foreign_new_for_display (gdk_display_get_default (), parent_xid);
 }
 
 gboolean
@@ -1945,7 +1945,6 @@ brasero_app_create_mainwin (BraseroApp *app)
 	priv->statusbar2 = gtk_statusbar_new ();
 	gtk_widget_show (priv->statusbar2);
 	priv->tooltip_ctx = gtk_statusbar_get_context_id (GTK_STATUSBAR (priv->statusbar2), "tooltip_info");
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (priv->statusbar2), FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox), priv->statusbar2, FALSE, TRUE, 0);
 
 	priv->statusbar1 = gtk_statusbar_new ();
@@ -2000,16 +1999,14 @@ brasero_app_create_mainwin (BraseroApp *app)
 }
 
 static void
-brasero_app_prepare_activation (GApplication *gapp,
-                                GVariant *arguments,
-                                GVariant *platform_data,
-                                BraseroApp *app)
+brasero_app_activate (GApplication *gapp,
+                      BraseroApp *app)
 {
 	BraseroAppPrivate *priv;
 
 	priv = BRASERO_APP_PRIVATE (app);
 
-	/* Except if we are supposed to quit show the window */
+	/* Except if we are supposed to quit, show the window */
 	if (priv->mainwin_running) {
 		gtk_widget_show (priv->mainwin);
 		gtk_window_present (GTK_WINDOW (priv->mainwin));
@@ -2031,8 +2028,8 @@ brasero_app_run_mainwin (BraseroApp *app)
 
 	if (priv->gapp)
 		g_signal_connect (priv->gapp,
-				  "prepare-activation",
-				  G_CALLBACK (brasero_app_prepare_activation),
+				  "activate",
+				  G_CALLBACK (brasero_app_activate),
 				  app);
 	gtk_main ();
 	return TRUE;
